service

package
v0.0.0-...-3d66bd6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2021 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewGapService

func NewGapService(name string) *gatt.Service

NewGapService : default GAP service NOTE: OS X provides GAP and GATT services, and they can't be customized. For Linux/Embedded, however, this is something we want to fully control.

func NewGattService

func NewGattService() *gatt.Service

NewGattService : default GATT service

func NewGeneratorAdminService

func NewGeneratorAdminService(generatorAdminServer handlers.GrpcServer, configuration map[string]string) *gatt.Service

NewGeneratorAdminService : relays requests to GeneratorAdmin via grps and sends responses back as notifications

Types

type AddIdentityProvider

type AddIdentityProvider struct {
	GeneratorServiceEndpointCommon
}

AddIdentityProvider :

type AddWallet

type AddWallet struct {
	GeneratorServiceEndpointCommon
}

AddWallet :

type ApproveWalletSharingRequest

type ApproveWalletSharingRequest struct {
	GeneratorServiceEndpointCommon
}

ApproveWalletSharingRequest :

type BleAdapter

type BleAdapter struct {
	GattService          *gatt.Service
	GeneratorAdminServer handlers.GrpcServer
	Configuration        map[string]string
}

BleAdapter :

func NewBleAdapter

func NewBleAdapter(GattService *gatt.Service, generatorAdminServer handlers.GrpcServer, configuration map[string]string) *BleAdapter

NewBleAdapter :

type ConfirmIdentityProvider

type ConfirmIdentityProvider struct {
	GeneratorServiceEndpointCommon
}

ConfirmIdentityProvider :

type DeleteWalletSharingRequest

type DeleteWalletSharingRequest struct {
	GeneratorServiceEndpointCommon
}

DeleteWalletSharingRequest :

type GeneratorServiceEndpoint

type GeneratorServiceEndpoint interface {
	// contains filtered or unexported methods
}

GeneratorServiceEndpoint :

type GeneratorServiceEndpointCommon

type GeneratorServiceEndpointCommon struct {
	Name                 string
	WriteHandlerUUID     string
	NotifyHandlerUUID    string
	GeneratorAdminServer handlers.GrpcServer
	Configuration        map[string]string
	GeneratorServiceEndpoint
}

GeneratorServiceEndpointCommon :

type GetEndPointsDescriptors

type GetEndPointsDescriptors struct {
	GeneratorServiceEndpointCommon
}

GetEndPointsDescriptors

type GetWalletSharingRequests

type GetWalletSharingRequests struct {
	GeneratorServiceEndpointCommon
}

GetWalletSharingRequests :

type ListIdentityProviders

type ListIdentityProviders struct {
	GeneratorServiceEndpointCommon
}

ListIdentityProviders :

type ListNonRegisteredDevices

type ListNonRegisteredDevices struct {
	GeneratorServiceEndpointCommon
}

ListNonRegisteredDevices :

type ListWallets

type ListWallets struct {
	GeneratorServiceEndpointCommon
}

ListWallets :

type RegisterDevice

type RegisterDevice struct {
	GeneratorServiceEndpointCommon
}

RegisterDevice :

Jump to